@@ -321,7 +321,6 @@ class Loaf:
             setValues = setValues[:-2]
         else:
             raise Exception("Invalid COLUMNS or VALUES type.")
-        print(setValues)
         self.query(f"UPDATE {table} SET {setValues} WHERE {where}")
 
     # Get all values from a table.
@@ -393,7 +392,7 @@ def parse(value):
     if isinstance(value, int):
         return str(value)
     if isinstance(value, datetime.date):
-        return value.strftime("%Y-%m-%d")
+        return "'" + value.strftime("%Y-%m-%d") + "'"
     return "'" + str(value).replace("'", "''") + "'"
 
 # Parses a value to a colored string to be used in tables.
